/*
 * Garoon Portal sample program
 * Copyright (c) 2016 Cybozu
 *
 * Licensed under the MIT License
 * https://opensource.org/licenses/mit-license.php
 */

(function($) {

    //---- settings ----//{{{

    var TOPIC_ID = 301;


    //function to escape html
    function escapeHtml(str) {
        if (!str) {
            return '';
        }
        return str
            .replace(/&/g, '&amp;')
            .replace(/</g, '&lt;')
            .replace(/>/g, '&gt;')
            .replace(/"/g, '&quot;')
            .replace(/'/g, '&#39;');
    }


    //function to get localTime from utcTime
    function toLocalTime(utcTime) {
        var localTime = moment.utc(utcTime.slice(0, -1)).toDate();
        localTime = moment(localTime).format('MM-DD-HH-mm');
        return localTime;
    }

    //---- settings ----//}}}


    //---- xml settings ----//{{{

    //function to make XML Header for Garoon API
    //arg1:services:service type (base,schedule)
    //arg2:action:name of API
    //return:XML header string
    function makeXMLHeader(services, action) {
        var xmlns;
        switch (services) {
            case 'base':
                xmlns = 'base_services="http://wsdl.cybozu.co.jp/base/2008"';
                break;
            case 'bulletin':
                xmlns = 'workflow_services="http://wsdl.cybozu.co.jp/bulletin/2008"';
                break;
            default:
                alert('Can not select services');
                return;
        }

        var xmlHeader =
            '<?xml version="1.0" encoding="UTF-8"?>' +
            '<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://www.w3.org/2003/05/soap-envelope" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" xmlns:' + xmlns + '>' +
            '<SOAP-ENV:Header>' +
               '<Action SOAP-ENV:mustUnderstand="1" xmlns="http://schemas.xmlsoap.org/ws/2003/03/addressing">' + escapeHtml(action) + '</Action>' +
               '<Timestamp SOAP-ENV:mustUnderstand="1" Id="id" xmlns="http://schemas.xmlsoap.org/ws/2002/07/utility">' +
                   '<Created>2037-08-12T14:45:00Z</Created>' +
                   '<Expires>2037-08-12T14:45:00Z</Expires>' +
               '</Timestamp>' +
               '<Locale>jp</Locale>' +
            '</SOAP-ENV:Header>';
        return xmlHeader;
    }


    //function to set XMLHTTP
    //return xmlhttp object
    function setXMLHTTP() {
        var xmlhttp = false;
        if(typeof ActiveXObject !== undefined) {
            try {
                xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
            } catch (e) {
                xmlhttp = false;
            }
        }
        if(!xmlhttp && typeof XMLHttpRequest !== undefined) {
            xmlhttp = new XMLHttpRequest();
        }
        return xmlhttp;
    }

    //---- xml settings end ----//}}}


    //---- getGrnData ----//{{{

    function getNewestFollow() {
        return new Promise(function (resolve, reject) {
            var xhrForFollow = setXMLHTTP();
            var url = '/g/cbpapi/bulletin/api.csp';
            var apiName = 'BulletinGetFollows';

            var followRequest =
                makeXMLHeader('bulletin', apiName) +
                '<SOAP-ENV:Body>' +
                    '<' + apiName + '>' +
                        '<parameters topic_id="' + TOPIC_ID + '" offset="0" limit="1"></parameters>' +
                    '</' + apiName + '>' +
                '</SOAP-ENV:Body>' +
                '</SOAP-ENV:Envelope>';
            console.log(followRequest);

            xhrForFollow.open('POST', url, true);
            xhrForFollow.onload = function() {
                if (xhrForFollow.readyState === 4 && xhrForFollow.status === 200) {
                    resolve(xhrForFollow.responseXML.getElementsByTagName('follow')[0]);
                }
            };
            xhrForFollow.send(followRequest);
        });
    }

    //---- getGrnData finish ----//}}}


    //---- showPortlet ----//{{{

    //---- makeHtml ----//{{{
    function makeSignageHtml(newestFollow) {
        var number = newestFollow.getAttribute('number');
        var text = newestFollow.getAttribute('text');
        return '<div class="marquee ledText01"><p>' + text + '</p></div>';
        //"/g/bulletin/view.csp?cid=1&aid=14&follow_id_autolink=3#follow"
    }

    //---- makeHtml end ----//}}}

    function showSignage(newestFollow) {
        console.log(newestFollow);
        var number = newestFollow.getAttribute('number');
        var text = newestFollow.getAttribute('text');
        var signageHtml = makeSignageHtml(newestFollow);
        $('#signage').append(signageHtml);
        $('.marquee p').marquee();
    }

    //----showPortlet finish----//}}}


    getNewestFollow()
        .then(showSignage, function(e) {
            console.log(e);
        });


})(jQuery);
